/**
  ******************************************************************************
  * File Name          : adc.h
  * Description        : ADC defines
  ******************************************************************************
  */
/* Define to prevent recursive inclusion -------------------------------------*/
#ifndef __ADC_H
#define __ADC_H

#include "stm32f7xx_hal.h"
#include "main.h"

#define MONO_SWITCH_PIN		IO_3_PIN
#define MONO_SWITCH_PORT	IO_3_PORT
#define MONO_LED_PIN		LED1_PIN
#define MONO_LED_PORT		LED1_PORT
#define CLIP_CH1_LED_PIN	LED2_PIN
#define CLIP_CH1_LED_PORT	LED2_PORT
#define CLIP_CH2_LED_PIN	LED3_PIN
#define CLIP_CH2_LED_PORT	LED3_PORT

#define LED_ON(PIN, PORT)	HAL_GPIO_WritePin(PORT, PIN, GPIO_PIN_SET)
#define LED_OFF(PIN, PORT)	HAL_GPIO_WritePin(PORT, PIN, GPIO_PIN_RESET)

void ADC_Init(void);
void ADC_DeInit(void);
void ADC_Status(void);
void ADC_Reset(void);
void ADC_SetFS(uint32_t fs);
void ADC_Record(void);
void ADC_SetMono(bool mono);
void ADC_SetFilter(uint8_t filter);
void ADC_SetPeakDetector(uint8_t channel, bool enable);
void ADC_SetPeakDetectorLevel(uint8_t channel, uint8_t level);
void ADC_SetRegister(uint8_t address, uint8_t reg, uint8_t value);
uint16_t ADC_LoadConfig(void);
uint16_t ADC_SaveConfig(void);
void ADC_InitConfig(void);

typedef union {
	uint32_t data;
	struct {
	uint8_t filter					: 8;
	bool mono						: 1;
	bool clipDetection				: 1;
	uint8_t peakDetectorLevel_ch1	: 8;
	uint8_t peakDetectorLevel_ch2	: 8;
	} config;
#ifdef X
	int16_t thd_c2_l;
	int16_t thd_c2_r;
	int16_t thd_c3_l;
	int16_t thd_c3_r;
#endif
} ADC_ConfigTypeDef;

extern I2C_HandleTypeDef *adc_i2c;
extern ADC_ConfigTypeDef adc_config;

#endif /* __ADC_H */
