/**
  ******************************************************************************
  * @file           : usb_device.c
  * @version        : v1.0
  * @brief          : This file implements the USB Device
  ******************************************************************************
  */

#include "usb_device.h"
#include "usbd_core.h"
#include "usbd_desc.h"
#include "usbd_audio.h"
#include "usbd_audio_if.h"
#include "usbd_composite.h"
#include "usbd_custom_hid_if.h"

/* USB Device Core handle declaration. */
USBD_HandleTypeDef hUsbDevice __attribute__ ((aligned(4)));

/**
  * Init USB device Library, add supported class and start the library
  * @retval None
  */
void USB_DEVICE_Init(void)
{
	// Init composite device
	USBD_COMPOSITE_Mount_Class();

	/* Init Device Library, add supported class and start the library. */
	if (USBD_Init(&hUsbDevice, &USBD_Desc, DEVICE_HS) != USBD_OK) {
		Error_Handler();
	}
	if (USBD_RegisterClass(&hUsbDevice, &USBD_COMPOSITE) != USBD_OK) {
	    Error_Handler();
	}
#ifdef USBD_USE_AUDIO
//	if (USBD_RegisterClass(&hUsbDevice, USBD_AUDIO_CLASS) != USBD_OK) {
//		Error_Handler();
//	}
//	if (USBD_AUDIO_RegisterInterface(&hUsbDevice, &USBD_AUDIO_fops) != USBD_OK) {
//	    Error_Handler();
//	}
#endif
#ifdef USBD_USE_CUSTOM_HID
//	if (USBD_RegisterClass(&hUsbDevice, USBD_CUSTOM_HID_CLASS) != USBD_OK) {
//		Error_Handler();
//	}
	if (USBD_CUSTOM_HID_RegisterInterface(&hUsbDevice, &USBD_CustomHID_fops_HS) != USBD_OK) {
		Error_Handler();
	}
#endif
	if (USBD_Start(&hUsbDevice) != USBD_OK) {
		Error_Handler();
	}
}
